summaryrefslogtreecommitdiffstats
path: root/generic/tkImgPhoto.h
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-03 06:18:06 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-03 06:18:06 (GMT)
commit18cb58ab84107c6049642f8aea423dd75e25e4c1 (patch)
treef83a780af872b4a234297c9bbb482dbf1d078fb6 /generic/tkImgPhoto.h
parent066d6dcb874a4f9bae3ba8f4d8fd54e460413e88 (diff)
downloadtk-18cb58ab84107c6049642f8aea423dd75e25e4c1.zip
tk-18cb58ab84107c6049642f8aea423dd75e25e4c1.tar.gz
tk-18cb58ab84107c6049642f8aea423dd75e25e4c1.tar.bz2
Implement part of TIP #581: Master/Slave. Not complete yet, and also the change to TkGetGeomContainer/TkGetTransientContainer is left out for now.
Diffstat (limited to 'generic/tkImgPhoto.h')
-rw-r--r--generic/tkImgPhoto.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/generic/tkImgPhoto.h b/generic/tkImgPhoto.h
index 36bc6cb..90705e9 100644
--- a/generic/tkImgPhoto.h
+++ b/generic/tkImgPhoto.h
@@ -27,10 +27,11 @@
* Forward declarations of the structures we define.
*/
+#define PhotoMaster PhotoModel
typedef struct ColorTableId ColorTableId;
typedef struct ColorTable ColorTable;
typedef struct PhotoInstance PhotoInstance;
-typedef struct PhotoMaster PhotoMaster;
+typedef struct PhotoModel PhotoModel;
/*
* A signed 8-bit integral type. If chars are unsigned and the compiler isn't
@@ -140,8 +141,8 @@ struct ColorTable {
* Definition of the data associated with each photo image master.
*/
-struct PhotoMaster {
- Tk_ImageMaster tkMaster; /* Tk's token for image master. NULL means the
+struct PhotoModel {
+ Tk_ImageModel tkMaster; /* Tk's token for image model. NULL means the
* image is being deleted. */
Tcl_Interp *interp; /* Interpreter associated with the application
* using this image. */
@@ -168,7 +169,7 @@ struct PhotoMaster {
};
/*
* Bit definitions for the flags field of a PhotoMaster.
* COLOR_IMAGE: 1 means that the image has different color
* components.
* IMAGE_CHANGED: 1 means that the instances of this image need
@@ -195,7 +196,7 @@ struct PhotoMaster {
*/
struct PhotoInstance {
- PhotoMaster *masterPtr; /* Pointer to master for image. */
+ PhotoModel *masterPtr; /* Pointer to master for image. */
Display *display; /* Display for windows using this instance. */
Colormap colormap; /* The image may only be used in windows with
* this particular colormap. */
@@ -168,7 +169,7 @@ struct PhotoMaster {
};
/*
- * Bit definitions for the flags field of a PhotoMaster.
+ * Bit definitions for the flags field of a PhotoModel.
* COLOR_IMAGE: 1 means that the image has different color
* components.